from setuptools import setup, find_packages

setup(
    version=6.0,
    name='duang111',
    description="test.",
    author='iamduang',
    author_email='xx@xxx.com',
    url='https://github.com/canonical/subiquity',
    license="AGPLv3+",
    py_modules=['duang'],
)